diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/IDhApiConfigGroup.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/IDhApiConfigGroup.java
new file mode 100644
index 000000000..94fca3292
--- /dev/null
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/IDhApiConfigGroup.java
@@ -0,0 +1,15 @@
+package com.seibel.lod.api.items.interfaces.config;
+
+import com.seibel.lod.core.interfaces.dependencyInjection.IBindable;
+
+/**
+ * This interface is just used to organize API config groups so
+ * they can be more easily handled together.
+ *
+ * @author James Seibel
+ * @version 9-15-2022
+ */
+public interface IDhApiConfigGroup extends IBindable
+{
+
+}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/both/IDhApiWorldGenerationConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/both/IDhApiWorldGenerationConfig.java
index 52921b1b7..61c3f67fb 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/both/IDhApiWorldGenerationConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/both/IDhApiWorldGenerationConfig.java
@@ -23,7 +23,8 @@ import com.seibel.lod.api.items.enums.config.EBlocksToAvoid;
import com.seibel.lod.api.items.enums.config.EDistanceGenerationMode;
import com.seibel.lod.api.items.enums.config.EGenerationPriority;
import com.seibel.lod.api.items.enums.config.ELightGenerationMode;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' world generation configuration.
@@ -33,33 +34,33 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiWorldGenerationConfig
+public interface IDhApiWorldGenerationConfig extends IDhApiConfigGroup
{
/**
* Defines whether fake chunks will be generated
* outside Minecraft's vanilla render distance.
*/
- IDhApiConfig getEnableDistantWorldGenerationConfig();
+ IDhApiConfigValue getEnableDistantWorldGeneration();
/** Defines to what level fake chunks will be generated. */
- IDhApiConfig getDistantGeneratorDetailLevelConfig();
+ IDhApiConfigValue getDistantGeneratorDetailLevel();
/** Defines how generated fake chunks will be lit. */
- IDhApiConfig getLightingModeConfig();
+ IDhApiConfigValue getLightingMode();
/** Defines the order in which fake chunks will be generated. */
- IDhApiConfig getGenerationPriorityConfig();
+ IDhApiConfigValue getGenerationPriority();
/**
- * Defines what blocks will be ignored when generating LODs.
+ * Defines what blocks will be ignored when generating LODs.
*
* TODO if this isn't deprecated before 1.7 it should probably be moved to the graphics tab
* @deprecated this method won't be needed once we transition to an ID based save system
* (vs the color based system we have currently)
*/
@Deprecated
- IDhApiConfig getBlocksToAvoidConfig();
+ IDhApiConfigValue getBlocksToAvoid();
/**
* Defines if the color of avoided blocks will color the block below them.
@@ -70,7 +71,7 @@ public interface IDhApiWorldGenerationConfig
* (vs the color based system we have currently)
*/
@Deprecated
- IDhApiConfig getTintWithAvoidedBlocksConfig();
+ IDhApiConfigValue getTintWithAvoidedBlocks();
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiBuffersConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiBuffersConfig.java
index 1042129a7..fc176afbc 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiBuffersConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiBuffersConfig.java
@@ -20,7 +20,8 @@
package com.seibel.lod.api.items.interfaces.config.client;
import com.seibel.lod.api.items.enums.config.EGpuUploadMethod;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' OpenGL buffer configuration.
@@ -28,11 +29,11 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiBuffersConfig
+public interface IDhApiBuffersConfig extends IDhApiConfigGroup
{
/** Defines how geometry data is uploaded to the GPU. */
- IDhApiConfig getGpuUploadMethodConfig();
+ IDhApiConfigValue getGpuUploadMethod();
/**
* Defines how long we should wait after uploading one
@@ -41,6 +42,6 @@ public interface IDhApiBuffersConfig
* This can be set to a non-zero number to reduce stuttering caused by
* uploading buffers to the GPU.
*/
- IDhApiConfig getBufferUploadTimeoutPerMegabyteInMillisecondsConfig();
+ IDhApiConfigValue getBufferUploadTimeoutPerMegabyteInMilliseconds();
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiDebuggingConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiDebuggingConfig.java
index 518963eb1..d91593abd 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiDebuggingConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiDebuggingConfig.java
@@ -20,7 +20,8 @@
package com.seibel.lod.api.items.interfaces.config.client;
import com.seibel.lod.api.items.enums.rendering.EDebugMode;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' debug configuration.
@@ -28,13 +29,13 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiDebuggingConfig
+public interface IDhApiDebuggingConfig extends IDhApiConfigGroup
{
/** Can be used to debug the standard fake chunk rendering. */
- IDhApiConfig getDebugRenderModeConfig();
+ IDhApiConfigValue getDebugRenderMode();
/** If enabled debug keybindings can be used. */
- IDhApiConfig getEnableDebugKeybindingsConfig();
+ IDhApiConfigValue getEnableDebugKeybindings();
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsFogConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsFogConfig.java
index b9559fb9c..221e88276 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsFogConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsFogConfig.java
@@ -20,8 +20,8 @@
package com.seibel.lod.api.items.interfaces.config.client;
import com.seibel.lod.api.items.enums.rendering.*;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' fog configuration.
@@ -33,7 +33,7 @@ import com.seibel.lod.api.items.objects.config.DhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiGraphicsFogConfig
+public interface IDhApiGraphicsFogConfig extends IDhApiConfigGroup
{
//====================//
@@ -41,19 +41,19 @@ public interface IDhApiGraphicsFogConfig
//====================//
/** Defines at what distance fog is rendered on fake chunks. */
- IDhApiConfig getFogDistanceConfig();
+ IDhApiConfigValue getFogDistance();
/** Should be used to enable/disable fog rendering. */
- IDhApiConfig getFogRenderConfig();
+ IDhApiConfigValue getFogRender();
/** Can be used to enable support with mods that change vanilla MC's fog color. */
- IDhApiConfig getFogColorConfig();
+ IDhApiConfigValue getFogColor();
/**
* If enabled attempts to disable vanilla MC's fog on real chunks.
* May not play nice with other fog editing mods.
*/
- IDhApiConfig getDisableVanillaFogConfig();
+ IDhApiConfigValue getDisableVanillaFog();
//=======================//
@@ -68,7 +68,7 @@ public interface IDhApiGraphicsFogConfig
* 0.0 = fog starts at the camera
* 1.0 = fog starts at the edge of the fake chunk render distance
*/
- IDhApiConfig getFogStartDistanceConfig();
+ IDhApiConfigValue getFogStartDistance();
/**
* Defines where the fog ends as a percent of the radius
@@ -78,19 +78,19 @@ public interface IDhApiGraphicsFogConfig
* 0.0 = fog ends at the camera
* 1.0 = fog ends at the edge of the fake chunk render distance
*/
- IDhApiConfig getFogEndDistanceConfig();
+ IDhApiConfigValue getFogEndDistance();
/** Defines how opaque the fog is at its thinnest point. */
- IDhApiConfig getFogMinThicknessConfig();
+ IDhApiConfigValue getFogMinThickness();
/** Defines how opaque the fog is at its thickest point. */
- IDhApiConfig getFogMaxThicknessConfig();
+ IDhApiConfigValue getFogMaxThickness();
/** Defines how the fog changes in thickness. */
- IDhApiConfig getFogFalloffConfig();
+ IDhApiConfigValue getFogFalloff();
/** Defines the fog density. */
- IDhApiConfig getFogDensityConfig();
+ IDhApiConfigValue getFogDensity();
//=====================//
@@ -98,33 +98,33 @@ public interface IDhApiGraphicsFogConfig
//=====================//
/** Defines how the height fog mixes. */
- IDhApiConfig getHeightFogMixModeConfig();
+ IDhApiConfigValue getHeightFogMixMode();
/** Defines how the height fog is drawn relative to the camera or world. */
- IDhApiConfig getHeightFogModeConfig();
+ IDhApiConfigValue getHeightFogMode();
/**
- * Defines the height fog's base height if {@link IDhApiGraphicsFogConfig#getHeightFogModeConfig()}
+ * Defines the height fog's base height if {@link IDhApiGraphicsFogConfig#getHeightFogMode()}
* is set to use a specific height.
*/
- IDhApiConfig getHeightFogBaseHeightConfig();
+ IDhApiConfigValue getHeightFogBaseHeight();
/** Defines the height fog's starting height as a percent of the world height. */
- IDhApiConfig getHeightFogStartingHeightPercentConfig();
+ IDhApiConfigValue getHeightFogStartingHeightPercent();
/** Defines the height fog's ending height as a percent of the world height. */
- IDhApiConfig getHeightFogEndingHeightPercentConfig();
+ IDhApiConfigValue getHeightFogEndingHeightPercent();
/** Defines how opaque the height fog is at its thinnest point. */
- IDhApiConfig getHeightFogMinThicknessConfig();
+ IDhApiConfigValue getHeightFogMinThickness();
/** Defines how opaque the height fog is at its thickest point. */
- IDhApiConfig getHeightFogMaxThicknessConfig();
+ IDhApiConfigValue getHeightFogMaxThickness();
/** Defines how the height fog changes in thickness. */
- IDhApiConfig getHeightFogFalloffConfig();
+ IDhApiConfigValue getHeightFogFalloff();
/** Defines the height fog's density. */
- IDhApiConfig getHeightFogDensityConfig();
+ IDhApiConfigValue getHeightFogDensity();
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiMultiplayerConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiMultiplayerConfig.java
index bc52fe42b..0541ea72a 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiMultiplayerConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiMultiplayerConfig.java
@@ -20,7 +20,8 @@
package com.seibel.lod.api.items.interfaces.config.client;
import com.seibel.lod.api.items.enums.config.EServerFolderNameMode;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' client-side multiplayer configuration.
@@ -28,14 +29,14 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiMultiplayerConfig
+public interface IDhApiMultiplayerConfig extends IDhApiConfigGroup
{
/**
* Defines how multiplayer server folders are named.
* Note: Changing this while connected to a multiplayer world will cause undefined behavior!
*/
- IDhApiConfig getFolderSavingModeConfig();
+ IDhApiConfigValue getFolderSavingMode();
/**
* Defines the necessary similarity (as a percent) that two potential levels
@@ -46,7 +47,7 @@ public interface IDhApiMultiplayerConfig
* Setting this to a non-zero value allows for usage in servers that user Multiverse
* or similar mods.
*/
- IDhApiConfig getMultiverseSimilarityRequirementConfig();
+ IDhApiConfigValue getMultiverseSimilarityRequirement();
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiThreadingConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiThreadingConfig.java
index d92ac4c6f..b49f17aae 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiThreadingConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiThreadingConfig.java
@@ -19,7 +19,8 @@
package com.seibel.lod.api.items.interfaces.config.client;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' threading configuration.
@@ -27,7 +28,7 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiThreadingConfig
+public interface IDhApiThreadingConfig extends IDhApiConfigGroup
{
/**
@@ -47,7 +48,7 @@ public interface IDhApiThreadingConfig
* count of threads and then a double percent active config.
*/
@Deprecated
- IDhApiConfig getWorldGeneratorThreadConfig();
+ IDhApiConfigValue getWorldGeneratorThread();
// TODO the above should be replaced with these
// IDhApiConfig getWorldGeneratorThreadConfig()
@@ -58,6 +59,6 @@ public interface IDhApiThreadingConfig
/** Defines how many buffer (GPU Terrain data) builder threads are used. */
- IDhApiConfig getBufferBuilderThreadConfig();
+ IDhApiConfigValue getBufferBuilderThread();
}
diff --git a/api/src/main/java/com/seibel/lod/core/interfaces/dependencyInjection/ApiCoreInjectors.java b/api/src/main/java/com/seibel/lod/core/interfaces/dependencyInjection/ApiCoreInjectors.java
index a13bf05ec..e40b9724f 100644
--- a/api/src/main/java/com/seibel/lod/core/interfaces/dependencyInjection/ApiCoreInjectors.java
+++ b/api/src/main/java/com/seibel/lod/core/interfaces/dependencyInjection/ApiCoreInjectors.java
@@ -1,5 +1,6 @@
package com.seibel.lod.core.interfaces.dependencyInjection;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
import com.seibel.lod.core.DependencyInjection.DhApiEventInjector;
/**
@@ -8,15 +9,24 @@ import com.seibel.lod.core.DependencyInjection.DhApiEventInjector;
* IE: this is how Core and the API talk to each other.
*
* @author James Seibel
- * @version 2022-9-13
+ * @version 2022-9-15
*/
public class ApiCoreInjectors
{
private static ApiCoreInjectors INSTANCE;
- public final IDhApiEventInjector eventInjector = new DhApiEventInjector();
+ public final IDhApiEventInjector events = new DhApiEventInjector();
+
+ /**
+ * WARNING: will be null until after DH initializes for the first time.
+ *
+ * Use a {@link com.seibel.lod.api.methods.events.abstractEvents.DhApiAfterDhInitEvent DhApiAfterDhInitEvent}
+ * along with the {@link ApiCoreInjectors#events ApiCoreInjectors.events} to be notified when this can
+ * be safely used.
+ */
+ public IDhApiConfig configs;
public static ApiCoreInjectors getInstance()
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/both/DhApiWorldGenerationConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/both/DhApiWorldGenerationConfig.java
index 6b10e3357..f24219ded 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/both/DhApiWorldGenerationConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/both/DhApiWorldGenerationConfig.java
@@ -19,9 +19,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.both;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.both.IDhApiWorldGenerationConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.WorldGenerator;
import com.seibel.lod.api.items.enums.config.EBlocksToAvoid;
import com.seibel.lod.api.items.enums.config.EDistanceGenerationMode;
@@ -38,32 +38,37 @@ import com.seibel.lod.api.items.enums.config.ELightGenerationMode;
*/
public class DhApiWorldGenerationConfig implements IDhApiWorldGenerationConfig
{
+ public static DhApiWorldGenerationConfig INSTANCE = new DhApiWorldGenerationConfig();
+
+ private DhApiWorldGenerationConfig() { }
+
+
@Override
- public IDhApiConfig getEnableDistantWorldGenerationConfig()
- { return new DhApiConfig<>(WorldGenerator.enableDistantGeneration); }
+ public IDhApiConfigValue getEnableDistantWorldGeneration()
+ { return new DhApiConfigValue<>(WorldGenerator.enableDistantGeneration); }
@Override
- public IDhApiConfig getDistantGeneratorDetailLevelConfig()
- { return new DhApiConfig<>(WorldGenerator.distanceGenerationMode); }
+ public IDhApiConfigValue getDistantGeneratorDetailLevel()
+ { return new DhApiConfigValue<>(WorldGenerator.distanceGenerationMode); }
@Override
- public IDhApiConfig getLightingModeConfig()
- { return new DhApiConfig<>(WorldGenerator.lightGenerationMode); }
+ public IDhApiConfigValue getLightingMode()
+ { return new DhApiConfigValue<>(WorldGenerator.lightGenerationMode); }
@Override
- public IDhApiConfig getGenerationPriorityConfig()
- { return new DhApiConfig<>(WorldGenerator.generationPriority); }
+ public IDhApiConfigValue getGenerationPriority()
+ { return new DhApiConfigValue<>(WorldGenerator.generationPriority); }
@Deprecated
@Override
- public IDhApiConfig getBlocksToAvoidConfig()
- { return new DhApiConfig<>(WorldGenerator.blocksToAvoid); }
+ public IDhApiConfigValue getBlocksToAvoid()
+ { return new DhApiConfigValue<>(WorldGenerator.blocksToAvoid); }
@Deprecated
@Override
- public IDhApiConfig getTintWithAvoidedBlocksConfig()
- { return new DhApiConfig<>(WorldGenerator.tintWithAvoidedBlocks); }
+ public IDhApiConfigValue getTintWithAvoidedBlocks()
+ { return new DhApiConfigValue<>(WorldGenerator.tintWithAvoidedBlocks); }
}
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiBuffersConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiBuffersConfig.java
index b91a689d7..74e2ad9b0 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiBuffersConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiBuffersConfig.java
@@ -19,9 +19,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiBuffersConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.Advanced.Buffers;
import com.seibel.lod.api.items.enums.config.EGpuUploadMethod;
@@ -33,11 +33,16 @@ import com.seibel.lod.api.items.enums.config.EGpuUploadMethod;
*/
public class DhApiBuffersConfig implements IDhApiBuffersConfig
{
+ public static DhApiBuffersConfig INSTANCE = new DhApiBuffersConfig();
- public IDhApiConfig getGpuUploadMethodConfig()
- { return new DhApiConfig<>(Buffers.gpuUploadMethod); }
+ private DhApiBuffersConfig() { }
- public IDhApiConfig getBufferUploadTimeoutPerMegabyteInMillisecondsConfig()
- { return new DhApiConfig<>(Buffers.gpuUploadPerMegabyteInMilliseconds); }
+
+
+ public IDhApiConfigValue getGpuUploadMethod()
+ { return new DhApiConfigValue<>(Buffers.gpuUploadMethod); }
+
+ public IDhApiConfigValue getBufferUploadTimeoutPerMegabyteInMilliseconds()
+ { return new DhApiConfigValue<>(Buffers.gpuUploadPerMegabyteInMilliseconds); }
}
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiDebuggingConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiDebuggingConfig.java
index 56265d915..b3b55a98f 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiDebuggingConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiDebuggingConfig.java
@@ -19,9 +19,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiDebuggingConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.Advanced.Debugging;
import com.seibel.lod.api.items.enums.rendering.EDebugMode;
@@ -33,11 +33,16 @@ import com.seibel.lod.api.items.enums.rendering.EDebugMode;
*/
public class DhApiDebuggingConfig implements IDhApiDebuggingConfig
{
+ public static DhApiDebuggingConfig INSTANCE = new DhApiDebuggingConfig();
- public IDhApiConfig getDebugRenderModeConfig()
- { return new DhApiConfig<>(Debugging.debugMode); }
+ private DhApiDebuggingConfig() { }
- public IDhApiConfig getEnableDebugKeybindingsConfig()
- { return new DhApiConfig<>(Debugging.enableDebugKeybindings); }
+
+
+ public IDhApiConfigValue getDebugRenderMode()
+ { return new DhApiConfigValue<>(Debugging.debugMode); }
+
+ public IDhApiConfigValue getEnableDebugKeybindings()
+ { return new DhApiConfigValue<>(Debugging.enableDebugKeybindings); }
}
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsConfig.java
index 641a5b775..9e86d725b 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsConfig.java
@@ -20,9 +20,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
import com.seibel.lod.api.items.enums.config.*;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiGraphicsConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.interfaces.config.converters.RenderModeEnabledConverter;
import com.seibel.lod.core.config.Config;
import com.seibel.lod.api.items.enums.rendering.ERendererMode;
@@ -38,22 +38,27 @@ import com.seibel.lod.core.config.Config.Client.Graphics.AdvancedGraphics;
*/
public class DhApiGraphicsConfig implements IDhApiGraphicsConfig
{
+ public static DhApiGraphicsConfig INSTANCE = new DhApiGraphicsConfig();
+
+ private DhApiGraphicsConfig() { }
+
+
//========================//
// basic graphic settings //
//========================//
@Override
- public IDhApiConfig getChunkRenderDistanceConfig()
- { return new DhApiConfig<>(Quality.lodChunkRenderDistance); }
+ public IDhApiConfigValue getChunkRenderDistance()
+ { return new DhApiConfigValue<>(Quality.lodChunkRenderDistance); }
@Override
- public IDhApiConfig getRenderingEnabledConfig()
- { return new DhApiConfig(Debugging.rendererMode, new RenderModeEnabledConverter()); }
+ public IDhApiConfigValue getRenderingEnabled()
+ { return new DhApiConfigValue(Debugging.rendererMode, new RenderModeEnabledConverter()); }
@Override
- public IDhApiConfig getRenderingModeConfig()
- { return new DhApiConfig<>(Debugging.rendererMode); }
+ public IDhApiConfigValue getRenderingMode()
+ { return new DhApiConfigValue<>(Debugging.rendererMode); }
@@ -62,20 +67,20 @@ public class DhApiGraphicsConfig implements IDhApiGraphicsConfig
//==================//
@Override
- public IDhApiConfig getMaxDetailLevelConfig()
- { return new DhApiConfig<>(Quality.drawResolution); }
+ public IDhApiConfigValue getMaxDetailLevel()
+ { return new DhApiConfigValue<>(Quality.drawResolution); }
@Override
- public IDhApiConfig getVerticalQualityConfig()
- { return new DhApiConfig<>(Quality.verticalQuality); }
+ public IDhApiConfigValue getVerticalQuality()
+ { return new DhApiConfigValue<>(Quality.verticalQuality); }
@Override
- public IDhApiConfig getHorizontalQualityDropoffConfig()
- { return new DhApiConfig<>(Quality.horizontalQuality); }
+ public IDhApiConfigValue getHorizontalQualityDropoff()
+ { return new DhApiConfigValue<>(Quality.horizontalQuality); }
@Override
- public IDhApiConfig getBiomeBlendingConfig()
- { return new DhApiConfig<>(Quality.lodBiomeBlending); }
+ public IDhApiConfigValue getBiomeBlending()
+ { return new DhApiConfigValue<>(Quality.lodBiomeBlending); }
@@ -84,48 +89,48 @@ public class DhApiGraphicsConfig implements IDhApiGraphicsConfig
//===========================//
@Override
- public IDhApiConfig getDisableDirectionalCullingConfig()
- { return new DhApiConfig<>(AdvancedGraphics.disableDirectionalCulling); }
+ public IDhApiConfigValue getDisableDirectionalCulling()
+ { return new DhApiConfigValue<>(AdvancedGraphics.disableDirectionalCulling); }
@Override
- public IDhApiConfig getVanillaOverdrawConfig()
- { return new DhApiConfig<>(AdvancedGraphics.vanillaOverdraw); }
+ public IDhApiConfigValue getVanillaOverdraw()
+ { return new DhApiConfigValue<>(AdvancedGraphics.vanillaOverdraw); }
@Override
- public IDhApiConfig getVanillaOverdrawOffsetConfig()
- { return new DhApiConfig<>(AdvancedGraphics.overdrawOffset); }
+ public IDhApiConfigValue getVanillaOverdrawOffset()
+ { return new DhApiConfigValue<>(AdvancedGraphics.overdrawOffset); }
@Override
- public IDhApiConfig getUseExtendedNearClipPlaneConfig()
- { return new DhApiConfig<>(AdvancedGraphics.useExtendedNearClipPlane); }
+ public IDhApiConfigValue getUseExtendedNearClipPlane()
+ { return new DhApiConfigValue<>(AdvancedGraphics.useExtendedNearClipPlane); }
@Override
- public IDhApiConfig getBrightnessMultiplierConfig()
- { return new DhApiConfig<>(AdvancedGraphics.brightnessMultiplier); }
+ public IDhApiConfigValue getBrightnessMultiplier()
+ { return new DhApiConfigValue<>(AdvancedGraphics.brightnessMultiplier); }
@Override
- public IDhApiConfig getSaturationMultiplierConfig()
- { return new DhApiConfig<>(AdvancedGraphics.saturationMultiplier); }
+ public IDhApiConfigValue getSaturationMultiplier()
+ { return new DhApiConfigValue<>(AdvancedGraphics.saturationMultiplier); }
@Override
- public IDhApiConfig getCaveCullingEnabledConfig()
- { return new DhApiConfig<>(AdvancedGraphics.enableCaveCulling); }
+ public IDhApiConfigValue getCaveCullingEnabled()
+ { return new DhApiConfigValue<>(AdvancedGraphics.enableCaveCulling); }
@Override
- public IDhApiConfig getCaveCullingHeightConfig()
- { return new DhApiConfig<>(AdvancedGraphics.caveCullingHeight); }
+ public IDhApiConfigValue getCaveCullingHeight()
+ { return new DhApiConfigValue<>(AdvancedGraphics.caveCullingHeight); }
@Override
- public IDhApiConfig getEarthCurvatureRatioConfig()
- { return new DhApiConfig<>(AdvancedGraphics.earthCurveRatio); }
+ public IDhApiConfigValue getEarthCurvatureRatio()
+ { return new DhApiConfigValue<>(AdvancedGraphics.earthCurveRatio); }
@Override
- public IDhApiConfig getEnableLodOnlyModeConfig()
- { return new DhApiConfig<>(Config.Client.Advanced.lodOnlyMode); }
+ public IDhApiConfigValue getEnableLodOnlyMode()
+ { return new DhApiConfigValue<>(Config.Client.Advanced.lodOnlyMode); }
@Override
- public IDhApiConfig getGeometryRebuildFrequencyConfig()
- { return new DhApiConfig<>(Config.Client.Advanced.Buffers.rebuildTimes); }
+ public IDhApiConfigValue getGeometryRebuildFrequency()
+ { return new DhApiConfigValue<>(Config.Client.Advanced.Buffers.rebuildTimes); }
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsFogConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsFogConfig.java
index 4726397eb..24b361eb7 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsFogConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiGraphicsFogConfig.java
@@ -20,9 +20,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
import com.seibel.lod.api.items.enums.rendering.*;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiGraphicsFogConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.Graphics.FogQuality;
/**
@@ -37,26 +37,31 @@ import com.seibel.lod.core.config.Config.Client.Graphics.FogQuality;
*/
public class DhApiGraphicsFogConfig implements IDhApiGraphicsFogConfig
{
+ public static DhApiGraphicsFogConfig INSTANCE = new DhApiGraphicsFogConfig();
+
+ private DhApiGraphicsFogConfig() { }
+
+
//====================//
// basic fog settings //
//====================//
@Override
- public IDhApiConfig getFogDistanceConfig()
- { return new DhApiConfig<>(FogQuality.fogDistance); }
+ public IDhApiConfigValue getFogDistance()
+ { return new DhApiConfigValue<>(FogQuality.fogDistance); }
@Override
- public IDhApiConfig getFogRenderConfig()
- { return new DhApiConfig<>(FogQuality.fogDrawMode); }
+ public IDhApiConfigValue getFogRender()
+ { return new DhApiConfigValue<>(FogQuality.fogDrawMode); }
@Override
- public IDhApiConfig getFogColorConfig()
- { return new DhApiConfig<>(FogQuality.fogColorMode); }
+ public IDhApiConfigValue getFogColor()
+ { return new DhApiConfigValue<>(FogQuality.fogColorMode); }
@Override
- public IDhApiConfig getDisableVanillaFogConfig()
- { return new DhApiConfig<>(FogQuality.disableVanillaFog); }
+ public IDhApiConfigValue getDisableVanillaFog()
+ { return new DhApiConfigValue<>(FogQuality.disableVanillaFog); }
//=======================//
@@ -64,28 +69,28 @@ public class DhApiGraphicsFogConfig implements IDhApiGraphicsFogConfig
//=======================//
@Override
- public IDhApiConfig getFogStartDistanceConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogStart); }
+ public IDhApiConfigValue getFogStartDistance()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogStart); }
@Override
- public IDhApiConfig getFogEndDistanceConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogEnd); }
+ public IDhApiConfigValue getFogEndDistance()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogEnd); }
@Override
- public IDhApiConfig getFogMinThicknessConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogMin); }
+ public IDhApiConfigValue getFogMinThickness()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogMin); }
@Override
- public IDhApiConfig getFogMaxThicknessConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogMax); }
+ public IDhApiConfigValue getFogMaxThickness()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogMax); }
@Override
- public IDhApiConfig getFogFalloffConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogType); }
+ public IDhApiConfigValue getFogFalloff()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogType); }
@Override
- public IDhApiConfig getFogDensityConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.farFogDensity); }
+ public IDhApiConfigValue getFogDensity()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.farFogDensity); }
//=====================//
@@ -93,39 +98,39 @@ public class DhApiGraphicsFogConfig implements IDhApiGraphicsFogConfig
//=====================//
@Override
- public IDhApiConfig getHeightFogMixModeConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogMixMode); }
+ public IDhApiConfigValue getHeightFogMixMode()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogMixMode); }
@Override
- public IDhApiConfig getHeightFogModeConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogMode); }
+ public IDhApiConfigValue getHeightFogMode()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogMode); }
@Override
- public IDhApiConfig getHeightFogBaseHeightConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogHeight); }
+ public IDhApiConfigValue getHeightFogBaseHeight()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogHeight); }
@Override
- public IDhApiConfig getHeightFogStartingHeightPercentConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogStart); }
+ public IDhApiConfigValue getHeightFogStartingHeightPercent()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogStart); }
@Override
- public IDhApiConfig getHeightFogEndingHeightPercentConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogEnd); }
+ public IDhApiConfigValue getHeightFogEndingHeightPercent()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogEnd); }
@Override
- public IDhApiConfig getHeightFogMinThicknessConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogMin); }
+ public IDhApiConfigValue getHeightFogMinThickness()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogMin); }
@Override
- public IDhApiConfig getHeightFogMaxThicknessConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogMax); }
+ public IDhApiConfigValue getHeightFogMaxThickness()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogMax); }
@Override
- public IDhApiConfig getHeightFogFalloffConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogType); }
+ public IDhApiConfigValue getHeightFogFalloff()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogType); }
@Override
- public IDhApiConfig getHeightFogDensityConfig()
- { return new DhApiConfig<>(FogQuality.AdvancedFog.HeightFog.heightFogDensity); }
+ public IDhApiConfigValue getHeightFogDensity()
+ { return new DhApiConfigValue<>(FogQuality.AdvancedFog.HeightFog.heightFogDensity); }
}
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiMultiplayerConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiMultiplayerConfig.java
index 7a97a3ff2..1460c5c8d 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiMultiplayerConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiMultiplayerConfig.java
@@ -19,9 +19,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiMultiplayerConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.Multiplayer;
import com.seibel.lod.api.items.enums.config.EServerFolderNameMode;
@@ -33,11 +33,16 @@ import com.seibel.lod.api.items.enums.config.EServerFolderNameMode;
*/
public class DhApiMultiplayerConfig implements IDhApiMultiplayerConfig
{
+ public static DhApiMultiplayerConfig INSTANCE = new DhApiMultiplayerConfig();
- public IDhApiConfig getFolderSavingModeConfig()
- { return new DhApiConfig<>(Multiplayer.serverFolderNameMode); }
+ private DhApiMultiplayerConfig() { }
- public IDhApiConfig getMultiverseSimilarityRequirementConfig()
- { return new DhApiConfig<>(Multiplayer.multiDimensionRequiredSimilarity); }
+
+
+ public IDhApiConfigValue getFolderSavingMode()
+ { return new DhApiConfigValue<>(Multiplayer.serverFolderNameMode); }
+
+ public IDhApiConfigValue getMultiverseSimilarityRequirement()
+ { return new DhApiConfigValue<>(Multiplayer.multiDimensionRequiredSimilarity); }
}
diff --git a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiThreadingConfig.java b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiThreadingConfig.java
index d60f3951a..2e24b217c 100644
--- a/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiThreadingConfig.java
+++ b/core/src/main/java/com/seibel/lod/core/api/external/coreImplementations/methods/config/client/DhApiThreadingConfig.java
@@ -19,9 +19,9 @@
package com.seibel.lod.core.api.external.coreImplementations.methods.config.client;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
import com.seibel.lod.api.items.interfaces.config.client.IDhApiThreadingConfig;
-import com.seibel.lod.api.items.objects.config.DhApiConfig;
+import com.seibel.lod.api.items.objects.config.DhApiConfigValue;
import com.seibel.lod.core.config.Config.Client.Advanced.Threading;
/**
@@ -32,11 +32,16 @@ import com.seibel.lod.core.config.Config.Client.Advanced.Threading;
*/
public class DhApiThreadingConfig implements IDhApiThreadingConfig
{
+ public static DhApiThreadingConfig INSTANCE = new DhApiThreadingConfig();
+
+ private DhApiThreadingConfig() { }
+
+
@Deprecated
@Override
- public IDhApiConfig getWorldGeneratorThreadConfig()
- { return new DhApiConfig<>(Threading.numberOfWorldGenerationThreads); }
+ public IDhApiConfigValue getWorldGeneratorThread()
+ { return new DhApiConfigValue<>(Threading.numberOfWorldGenerationThreads); }
// TODO the above should be replaced with these
// public static IDhApiConfig getWorldGeneratorThreadConfig()
@@ -46,7 +51,7 @@ public class DhApiThreadingConfig implements IDhApiThreadingConfig
// { return new DhApiConfig<>(Threading.ToBeDetermined); }
@Override
- public IDhApiConfig getBufferBuilderThreadConfig()
- { return new DhApiConfig<>(Threading.numberOfBufferBuilderThreads); }
+ public IDhApiConfigValue getBufferBuilderThread()
+ { return new DhApiConfigValue<>(Threading.numberOfBufferBuilderThreads); }
}
diff --git a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsConfig.java b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsConfig.java
index 9cc2d6d09..9fe1a7dc3 100644
--- a/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsConfig.java
+++ b/api/src/main/java/com/seibel/lod/api/items/interfaces/config/client/IDhApiGraphicsConfig.java
@@ -21,7 +21,8 @@ package com.seibel.lod.api.items.interfaces.config.client;
import com.seibel.lod.api.items.enums.config.*;
import com.seibel.lod.api.items.enums.rendering.ERendererMode;
-import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigValue;
+import com.seibel.lod.api.items.interfaces.config.IDhApiConfigGroup;
/**
* Distant Horizons' graphics/rendering configuration.
@@ -29,7 +30,7 @@ import com.seibel.lod.api.items.interfaces.config.IDhApiConfig;
* @author James Seibel
* @version 2022-9-15
*/
-public interface IDhApiGraphicsConfig
+public interface IDhApiGraphicsConfig extends IDhApiConfigGroup
{
//========================//
@@ -37,15 +38,15 @@ public interface IDhApiGraphicsConfig
//========================//
/** The distance is the radius measured in chunks. */
- IDhApiConfig getChunkRenderDistanceConfig();
+ IDhApiConfigValue getChunkRenderDistance();
/**
- * Simplified version of {@link IDhApiGraphicsConfig#getRenderingModeConfig()}
+ * Simplified version of {@link IDhApiGraphicsConfig#getRenderingMode()}
* that only enables/disables the fake chunk rendering.
*
* Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingModeConfig()}'s value.
*/
- IDhApiConfig getRenderingEnabledConfig();
+ IDhApiConfigValue getRenderingEnabled();
/**
* Can be used to enable/disable fake chunk rendering or enable the debug renderer.
@@ -53,9 +54,9 @@ public interface IDhApiGraphicsConfig
* The debug renderer is used to confirm rendering is working at and will draw
* a single multicolor rhombus on the screen in skybox space (AKA behind MC's rendering).
*
* Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingEnabledConfig()}'s value.
*/
- IDhApiConfig getRenderingModeConfig();
+ IDhApiConfigValue getRenderingMode();
@@ -64,13 +65,13 @@ public interface IDhApiGraphicsConfig
//==================//
/** Defines how detailed fake chunks are in the horizontal direction */
- IDhApiConfig getMaxDetailLevelConfig();
+ IDhApiConfigValue getMaxDetailLevel();
/** Defines how detailed fake chunks are in the vertical direction */
- IDhApiConfig getVerticalQualityConfig();
+ IDhApiConfigValue getVerticalQuality();
/** Modifies the quadratic function fake chunks use for horizontal quality drop-off. */
- IDhApiConfig getHorizontalQualityDropoffConfig();
+ IDhApiConfigValue getHorizontalQualityDropoff();
/**
* The same as vanilla Minecraft's biome blending.
@@ -80,7 +81,7 @@ public interface IDhApiGraphicsConfig
* 2 = blending of 5x5
* ...
*/
- IDhApiConfig getBiomeBlendingConfig();
+ IDhApiConfigValue getBiomeBlending();
@@ -89,13 +90,13 @@ public interface IDhApiGraphicsConfig
//===========================//
/** If directional culling is disabled fake chunks will be rendered behind the camera. */
- IDhApiConfig getDisableDirectionalCullingConfig();
+ IDhApiConfigValue getDisableDirectionalCulling();
/** Determines how fake chunks are rendered in comparison to vanilla MC's chunks. */
- IDhApiConfig getVanillaOverdrawConfig();
+ IDhApiConfigValue getVanillaOverdraw();
/** Modifies how far the vanilla overdraw is rendered in chunks. */
- IDhApiConfig getVanillaOverdrawOffsetConfig();
+ IDhApiConfigValue getVanillaOverdrawOffset();
/**
* If enabled the near clip plane is extended to reduce
@@ -103,34 +104,34 @@ public interface IDhApiGraphicsConfig
* Disabling this reduces holes in the world due to the near clip plane
* being too close to the camera and the terrain not being covered by vanilla terrain.
*/
- IDhApiConfig getUseExtendedNearClipPlaneConfig();
+ IDhApiConfigValue getUseExtendedNearClipPlane();
/**
* Modifies how bright fake chunks are.
* This is done when generating the vertex data and is applied before any shaders.
*/
- IDhApiConfig getBrightnessMultiplierConfig();
+ IDhApiConfigValue getBrightnessMultiplier();
/**
* Modifies how saturated fake chunks are.
* This is done when generating the vertex data and is applied before any shaders.
*/
- IDhApiConfig getSaturationMultiplierConfig();
+ IDhApiConfigValue getSaturationMultiplier();
/** Defines if Distant Horizons should attempt to cull fake chunk cave geometry. */
- IDhApiConfig getCaveCullingEnabledConfig();
+ IDhApiConfigValue getCaveCullingEnabled();
/** Defines what height cave culling should be used below if enabled. */
- IDhApiConfig getCaveCullingHeightConfig();
+ IDhApiConfigValue getCaveCullingHeight();
/** This ratio is relative to Earth's real world curvature. */
- IDhApiConfig getEarthCurvatureRatioConfig();
+ IDhApiConfigValue getEarthCurvatureRatio();
/** If enabled vanilla chunk rendering is disabled and only fake chunks are rendered. */
- IDhApiConfig getEnableLodOnlyModeConfig();
+ IDhApiConfigValue getEnableLodOnlyMode();
/** Defines how often the geometry should be rebuilt when the player moves. */
- IDhApiConfig getGeometryRebuildFrequencyConfig();
+ IDhApiConfigValue getGeometryRebuildFrequency();
@@ -37,15 +38,15 @@ public interface IDhApiGraphicsConfig
* that only enables/disables the fake chunk rendering.
*
- * Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingModeConfig()}'s value.
+ * Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingMode()}'s value.
*/
@@ -53,9 +54,9 @@ public interface IDhApiGraphicsConfig
* a single multicolor rhombus on the screen in skybox space (AKA behind MC's rendering).
*
- * Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingEnabledConfig()}'s value.
+ * Changing this config also changes {@link IDhApiGraphicsConfig#getRenderingEnabled()}'s value.
*/